Index: src/v8natives.js |
diff --git a/src/v8natives.js b/src/v8natives.js |
index 1ea3f412f815333e8d0d6e22d7d9eb4228ca5699..cbd8e14679687455ad3dfe9e3f0459d50a8dc527 100644 |
--- a/src/v8natives.js |
+++ b/src/v8natives.js |
@@ -44,10 +44,13 @@ function OverrideFunction(object, name, f) { |
// Helper function to install a getter-only accessor property. |
-function InstallGetter(object, name, getter) { |
+function InstallGetter(object, name, getter, attributes) { |
+ if (typeof attributes == "undefined") { |
+ attributes = DONT_ENUM; |
+ } |
%FunctionSetName(getter, name); |
%FunctionRemovePrototype(getter); |
%DefineAccessorPropertyUnchecked(object, name, getter, null, DONT_ENUM); |
%SetNativeFlag(getter); |
} |
@@ -44,10 +44,13 @@ function OverrideFunction(object, name, f) { |
%FunctionSetName(getter, name); |
%FunctionRemovePrototype(getter); |
- %DefineAccessorPropertyUnchecked(object, name, getter, null, DONT_ENUM); |
+ %DefineAccessorPropertyUnchecked(object, name, getter, null, attributes); |
%SetNativeFlag(getter); |
} |